@@ -67,3 +67,17 @@ colors.grey_shade = colors.grey.shade(25)
 colors.neutral = Color('neutral', 255*np.array([0.4824, 0.5216, 0.502]))
 colors.neutral_tint = colors.neutral.tint(50)
 colors.neutral_shade = colors.neutral.shade(50)
+
+# CABBI
+colors.CABBI_blue_light = Color('CABBI_blue_light', '#b2e0e5')
+colors.CABBI_blue = Color('CABBI_blue', '#82cfd0')
+colors.CABBI_teal = Color('CABBI_teal', '#00a996')
+colors.CABBI_teal_green = Color('CABBI_teal_green', '#1a8476')
+colors.CABBI_green_soft = Color('CABBI_green_soft', '#3ba459')
+colors.CABBI_green_dirty = Color('CABBI_green_dirty', '#8ead3e')
+colors.CABBI_green = Color('CABBI_green', '#007f3d')
+colors.CABBI_yellow = Color('CABBI_yellow', '#ffdd50')
+colors.CABBI_orange = Color('CABBI_orange', '#fcb813')
+colors.CABBI_grey = Color('CABBI_grey', '#e1deda')
+colors.CABBI_brown = Color('CABBI_brown', '#98876e')
+colors.CABBI_black = Color('CABBI_black', '#403a48')
\ No newline at end of file
